Tactic Client Library
=====================

This library is used to communicate with a tactic server.
It is available on PyPI to make installing with pip easier.

It also installs the two bin scripts: `get_ticket` and `create_project`.

Tactic
------

Tactic is an Asset Management System. It is written by Southpaw.
The code is taken from: `https://github.com/Southpaw-TACTIC/TACTIC/tree/4.8/src/client
<https://github.com/Southpaw-TACTIC/TACTIC/tree/4.8/src/client>`_.

For bugs relating to the packaging: `https://github.com/rvanlaar/tactic-client
<https://github.com/rvanlaar/tactic-client>`_.

For bugs relating to the actual code: `http://tacticopensource.com/forum
<http://tacticopensource.com/forum>`_.

Tests
-----

There are tests, but I'm not running them yet. So no guarentees.
